@@ -34,7 +34,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: DDS.cc 22560 2010-04-21 21:22:00Z jimg $"
+    {"$Id: DDS.cc 23577 2010-09-14 22:20:18Z jimg $"
     };
 
 #include <cstdio>
@@ -935,6 +935,12 @@ DDS::parse(FILE *in)
 void
 DDS::print(FILE *out)
 {
+#if 0
+    ostringstream oss;
+    print(oss);
+
+    fwrite(oss.str().c_str(), oss.str().length(), 1, out);
+#else
     fprintf(out, "Dataset {\n") ;
 
     for (Vars_citer i = vars.begin(); i != vars.end(); i++) {
@@ -944,6 +950,7 @@ DDS::print(FILE *out)
     fprintf(out, "} %s;\n", id2www(name).c_str()) ;
 
     return ;
+#endif
 }
 #endif
 
