@@ -35,7 +35,7 @@
 
 #include "config.h"
 
-//#define DODS_DEBUG
+// #define DODS_DEBUG
 
 #include <functional>
 #include <algorithm>
@@ -676,26 +676,30 @@ Grid::projection_yields_grid()
     if (!a->send_p())
         return false;
 
-    Array::Dim_iter i = a->dim_begin() ;
+    // If only one part is being sent, it's clearly not a grid (it must be
+    // the array part of the Grid that's being sent (given that the above
+    // test passed and the array is being sent).
+    if (components(true) == 1)
+	return false;
+
+    Array::Dim_iter d = a->dim_begin() ;
     Map_iter m = map_begin() ;
-    for (; valid && i != a->dim_end() && m != map_end(); i++, m++) {
-        if (a->dimension_size(i, true)) {
+
+    while (valid && d != a->dim_end() && m != map_end()) {
+	Array &map = dynamic_cast<Array&>(**m);
+        if (a->dimension_size(d, true) && map.send_p()) {
             // Check the matching Map vector; the Map projection must equal
             // the Array dimension projection
-            Array *map = (Array *)(*m);
-            Array::Dim_iter fd = map->dim_begin(); // Maps have only one dim!
-            valid = map->dimension_start(fd, true)
-                    == a->dimension_start(i, true)
-                    && map->dimension_stop(fd, true)
-                    == a->dimension_stop(i, true)
-                    && map->dimension_stride(fd, true)
-                    == a->dimension_stride(i, true);
+            Array::Dim_iter fd = map.dim_begin(); // Maps have only one dim!
+            valid = map.dimension_start(fd, true) == a->dimension_start(d, true)
+                    && map.dimension_stop(fd, true) == a->dimension_stop(d, true)
+                    && map.dimension_stride(fd, true) == a->dimension_stride(d, true);
         }
         else {
-            // Corresponding Map vector must be excluded from the projection.
-            Array *map = (Array *)(*m);
-            valid = !map->send_p();
+           valid = false;
         }
+
+	d++, m++;
     }
 
     return valid;
@@ -718,26 +722,6 @@ Grid::print_decl(FILE *out, string space, bool print_semi,
     if (constrained && !send_p())
         return;
 
-#if 0
-    // If we are printing the declaration of a constrained Grid then check for
-    // the case where the projection removes all but one component; the
-    // resulting object is a simple array.
-    int projection = components(true);
-    if (constrained && projection == 1) {
-        _array_var->print_decl(out, space, print_semi /*true*/, constraint_info,
-                               constrained);
-        for (Map_citer i = _map_vars.begin(); i != _map_vars.end(); i++) {
-            (*i)->print_decl(out, space, print_semi /*true*/, constraint_info, constrained);
-        }
-
-        goto exit;  // Skip end material.
-    }
-    // If there are M (< N) componets (Array and Maps combined) in a N
-    // component Grid, send the M components as elements of a Struture.
-    // This will preserve the grouping without violating the rules for a
-    // Grid.
-    // else
-#endif
     // The problem with the above is that if two Grids are projected and each
     // contain one variable, say a map, and it happens to have the same name
     // in each Grid, then without the enclosing Structures, the returned dataset
@@ -783,10 +767,6 @@ Grid::print_decl(FILE *out, string space, bool print_semi,
 
     if (print_semi)
         fprintf(out, ";\n") ;
-#if 0
-    // If sending just one comp, skip sending the terminal semicolon, etc.
-exit:
-#endif
 
     return;
 }
@@ -799,31 +779,6 @@ Grid::print_decl(ostream &out, string space, bool print_semi,
     if (constrained && !send_p())
         return;
 
-    // If we are printing the declaration of a constrained Grid then check for
-    // the case where the projection removes all but one component; the
-    // resulting object is a simple array.
-    //
-    // I replaced the 'true' with the value of 'print_semi' passed in by the
-    // caller. This fixes an issue with the intern_data tests and does not
-    // seem to break anything else. jhrg 11/9/07
-#if 0
-    int projection = components(true);
-    if (constrained && projection == 1) {
-        _array_var->print_decl(out, space, print_semi /*true*/, constraint_info,
-                               constrained);
-        for (Map_citer i = _map_vars.begin(); i != _map_vars.end(); i++) {
-            (*i)->print_decl(out, space, print_semi /*true*/, constraint_info, constrained);
-        }
-
-        goto exit;  // Skip end material.
-    }
-    // If there are M (< N) components (Array and Maps combined) in a N
-    // component Grid, send the M components as elements of a Structure.
-    // This will preserve the grouping without violating the rules for a
-    // Grid.
-    // else
-#endif
-
     // See comment for the FILE* version of this method.
     if (constrained && !projection_yields_grid()) {
 	out << space << "Structure {\n" ;
@@ -865,10 +820,6 @@ Grid::print_decl(ostream &out, string space, bool print_semi,
 
     if (print_semi)
 	out << ";\n" ;
-#if 0
-    // If sending just one comp, skip sending the terminal semicolon, etc.
-exit:
-#endif
 
     return;
 }
@@ -900,30 +851,6 @@ Grid::print_xml(FILE *out, string space, bool constrained)
     if (constrained && !send_p())
          return;
 
-     // If we are printing the declaration of a constrained Grid then check for
-     // the case where the projection removes all but one component; the
-     // resulting object is a simple array.
-     //
-     // I replaced the 'true' with the value of 'print_semi' passed in by the
-     // caller. This fixes an issue with the intern_data tests and does not
-     // seem to break anything else. jhrg 11/9/07
-#if 0
-     int projection = components(true);
-     if (constrained && projection == 1) {
-         get_attr_table().print_xml(out, space + "    ", constrained);
-
-         get_array()->print_xml(out, space + "    ", constrained);
-
-         for_each(map_begin(), map_end(),
-                  PrintMapField(out, space + "    ", constrained, "Array"));
-     }
-     // If there are M (< N) components (Array and Maps combined) in a N
-     // component Grid, send the M components as elements of a Structure.
-     // This will preserve the grouping without violating the rules for a
-     // Grid.
-     // else
-#endif
-
      if (constrained && !projection_yields_grid()) {
          fprintf(out, "%s<Structure", space.c_str());
          if (!name().empty())
@@ -987,30 +914,6 @@ Grid::print_xml(ostream &out, string space, bool constrained)
     if (constrained && !send_p())
         return;
 
-    // If we are printing the declaration of a constrained Grid then check for
-    // the case where the projection removes all but one component; the
-    // resulting object is a simple array.
-    //
-    // I replaced the 'true' with the value of 'print_semi' passed in by the
-    // caller. This fixes an issue with the intern_data tests and does not
-    // seem to break anything else. jhrg 11/9/07
-#if 0
-    int projection = components(true);
-    if (constrained && projection == 1) {
-        get_attr_table().print_xml(out, space + "    ", constrained);
-
-        get_array()->print_xml(out, space + "    ", constrained);
-
-        for_each(map_begin(), map_end(),
-                 PrintMapFieldStrm(out, space + "    ", constrained, "Array"));
-    }
-    // If there are M (< N) components (Array and Maps combined) in a N
-    // component Grid, send the M components as elements of a Structure.
-    // This will preserve the grouping without violating the rules for a
-    // Grid.
-    //else
-#endif
-
     if (constrained && !projection_yields_grid()) {
         out << space << "<Structure" ;
         if (!name().empty())
