@@ -545,6 +545,7 @@ HTTPCache::create_cache_root(const string &cache_root)
 
 #ifdef WIN32
     cur = cache_root[1] == ':' ? 3 : 1;
+    typedef int mode_t;
 #else
     cur = 1;
 #endif
@@ -934,9 +935,6 @@ HTTPCache::is_url_in_cache(const string &url)
     HTTPCacheTable::CacheEntry *entry = d_http_cache_table->get_locked_entry_from_cache_table(url);
     bool status = entry != 0;
     if (entry) {
-#if 0
-    	entry->unlock();
-#endif
         entry->unlock_read_response();
     }
     return  status;
@@ -1265,22 +1263,16 @@ HTTPCache::get_conditional_request_headers(const string &url)
             headers.push_back(string("If-Modified-Since: ")
                               + date_time_str(&expires));
         }
-#if 0
-		entry->unlock();
-#endif
-		entry->unlock_read_response();
-	    unlock_cache_interface();
+        entry->unlock_read_response();
+        unlock_cache_interface();
     }
     catch (...) {
-		unlock_cache_interface();
-		if (entry) {
-#if 0
-		    entry->unlock();
-#endif
-		    entry->unlock_read_response();
-		}
-		throw;
+	unlock_cache_interface();
+	if (entry) {
+	    entry->unlock_read_response();
 	}
+	throw;
+    }
 
     return headers;
 }
@@ -1354,18 +1346,12 @@ HTTPCache::update_response(const string &url, time_t request_time,
              back_inserter(result));
 
         write_metadata(entry->get_cachename(), result);
-#if 0
-        entry->unlock();
-#endif
         entry->unlock_write_response();
-		unlock_cache_interface();
+        unlock_cache_interface();
     }
     catch (...) {
         if (entry) {
-#if 0
-        	entry->unlock();
-#endif
-        	entry->unlock_read_response();
+            entry->unlock_read_response();
         }
         unlock_cache_interface();
         throw;
@@ -1409,9 +1395,6 @@ HTTPCache::is_url_valid(const string &url)
         // In case this entry is of type "must-revalidate" then we consider it
         // invalid.
         if (entry->get_must_revalidate()) {
-#if 0
-            entry->unlock();
-#endif
             entry->unlock_read_response();
             unlock_cache_interface();
             return false;
@@ -1424,9 +1407,6 @@ HTTPCache::is_url_valid(const string &url)
         // given in the request cache control header is followed.
         if (d_max_age >= 0 && current_age > d_max_age) {
             DBG(cerr << "Cache....... Max-age validation" << endl);
-#if 0
-            entry->unlock();
-#endif
             entry->unlock_read_response();
             unlock_cache_interface();
             return false;
@@ -1434,9 +1414,6 @@ HTTPCache::is_url_valid(const string &url)
         if (d_min_fresh >= 0
             && entry->get_freshness_lifetime() < current_age + d_min_fresh) {
             DBG(cerr << "Cache....... Min-fresh validation" << endl);
-#if 0
-            entry->unlock();
-#endif
             entry->unlock_read_response();
             unlock_cache_interface();
             return false;
@@ -1444,18 +1421,12 @@ HTTPCache::is_url_valid(const string &url)
 
         freshness = (entry->get_freshness_lifetime()
                      + (d_max_stale >= 0 ? d_max_stale : 0) > current_age);
-#if 0
-        entry->unlock();
-#endif
         entry->unlock_read_response();
         unlock_cache_interface();
     }
     catch (...) {
     	if (entry) {
-#if 0
-    		entry->unlock();
-#endif
-    		entry->unlock_read_response();
+    	    entry->unlock_read_response();
     	}
     	unlock_cache_interface();
         throw;
@@ -1521,9 +1492,6 @@ FILE * HTTPCache::get_cached_response(const string &url,
     }
     catch (...) {
         if (entry)
-#if 0
-        entry->unlock();
-#endif
         unlock_cache_interface();
         throw;
     }
