@@ -27,7 +27,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: HTTPConnect.cc 19864 2008-11-14 17:01:35Z jimg $"
+    { "$Id: HTTPConnect.cc 21699 2009-11-05 00:06:01Z jimg $"
     };
 
 #ifdef HAVE_UNISTD_H
@@ -49,8 +49,10 @@ static char rcsid[] not_used =
 
 //#define DODS_DEBUG
 //#define DODS_DEBUG2
+//#define HTTP_TRACE
 
 #include "debug.h"
+#include "mime_util.h"
 #include "GNURegex.h"
 #include "HTTPCache.h"
 #include "HTTPConnect.h"
@@ -75,7 +77,7 @@ int dods_keep_temps = 0;
 
 #define CLIENT_ERR_MIN 400
 #define CLIENT_ERR_MAX 417
-static char *http_client_errors[CLIENT_ERR_MAX - CLIENT_ERR_MIN +1] =
+static const char *http_client_errors[CLIENT_ERR_MAX - CLIENT_ERR_MIN +1] =
     {
         "Bad Request:",
         "Unauthorized: Contact the server administrator.",
@@ -101,7 +103,7 @@ static char *http_client_errors[CLIENT_ERR_MAX - CLIENT_ERR_MIN +1] =
 
 #define SERVER_ERR_MIN 500
 #define SERVER_ERR_MAX 505
-static char *http_server_errors[SERVER_ERR_MAX - SERVER_ERR_MIN +1] =
+static const char *http_server_errors[SERVER_ERR_MAX - SERVER_ERR_MIN +1] =
     {
         "Internal Server Error.",
         "Not Implemented.",
@@ -111,63 +113,6 @@ static char *http_server_errors[SERVER_ERR_MAX - SERVER_ERR_MIN +1] =
         "HTTP Version Not Supported."
     };
 
-/** This function returns the ObjectType value that matches the given string.
-    Modified to include tests for the descriptions that use hyphens in addition
-    to underscores. 8/1/08 jhrg
-
-    @deprecated Use get_description_type instead - there are two other get_type()
-    functions in libdap.*/
-ObjectType
-get_type(const string &value)
-{
-    if (value == "dods_das" | value == "dods-das")
-        return dods_das;
-    else if (value == "dods_dds" | value == "dods-dds")
-        return dods_dds;
-    else if (value == "dods_data" | value == "dods-data")
-        return dods_data;
-    else if (value == "dods_error" | value == "dods-error")
-        return dods_error;
-    else if (value == "web_error" | value == "web-error")
-        return web_error;
-    else if (value == "dap4_ddx" | value == "dap4-ddx")
-        return dap4_ddx;
-    else if (value == "dap4_datax" | value == "dap4-datax")
-        return dap4_datax;
-    else if (value == "dap4_errorx" | value == "dap4-errorx")
-        return dap4_errorx;
-    else
-        return unknown_type;
-}
-
-/** This function returns the ObjectType value that matches the given string.
-    Modified to include tests for the descriptions that use hyphens in addition
-    to underscores. 8/1/08 jhrg
-
-    @param value Value from teh HTTP response header */
-ObjectType
-get_description_type(const string &value)
-{
-    if (value == "dods_das" | value == "dods-das")
-        return dods_das;
-    else if (value == "dods_dds" | value == "dods-dds")
-        return dods_dds;
-    else if (value == "dods_data" | value == "dods-data")
-        return dods_data;
-    else if (value == "dods_error" | value == "dods-error")
-        return dods_error;
-    else if (value == "web_error" | value == "web-error")
-        return web_error;
-    else if (value == "dap4_ddx" | value == "dap4-ddx")
-        return dap4_ddx;
-    else if (value == "dap4_datax" | value == "dap4-datax")
-        return dap4_datax;
-    else if (value == "dap4_errorx" | value == "dap4-errorx")
-        return dap4_errorx;
-    else
-        return unknown_type;
-}
-
 /** This function translates the HTTP status codes into error messages. It
     works for those code greater than or equal to 400. */
 static string
@@ -196,60 +141,40 @@ public:
     ParseHeader() : type(unknown_type), server("dods/0.0"), protocol("2.0")
     { }
 
-    void operator()(const string &header)
+    void operator()(const string &line)
     {
-        std::istringstream line(header);
-
-        string name;
-        line >> name;
-        downcase(name);
-        if (name == "content-description:") {
-            string value;
-            line >> value;
-            downcase(value);
-            DBG2(cout << name << ": " << value << endl);
+        string name, value;
+        parse_mime_header(line, name, value);
+        if (name == "content-description") {
+            DBG2(cerr << name << ": " << value << endl);
             type = get_description_type(value);
         }
         // The second test (== "dods/0.0") tests if xopendap-server has already
         // been seen. If so, use that header in preference to the old
         // XDODS-Server header. jhrg 2/7/06
-        else if (name == "xdods-server:" && server == "dods/0.0") {
-            string value;
-            line >> value;
-            downcase(value);
-            DBG2(cout << name << ": " << value << endl);
+        else if (name == "xdods-server" && server == "dods/0.0") {
+            DBG2(cerr << name << ": " << value << endl);
             server = value;
         }
-        else if (name == "xopendap-server:") {
-            string value;
-            line >> value;
-            downcase(value);
-            DBG2(cout << name << ": " << value << endl);
+        else if (name == "xopendap-server") {
+            DBG2(cerr << name << ": " << value << endl);
             server = value;
         }
-        else if (name == "xdap:") {
-            string value;
-            line >> value;
-            downcase(value);
-            DBG2(cout << name << ": " << value << endl);
+        else if (name == "xdap") {
+            DBG2(cerr << name << ": " << value << endl);
             protocol = value;
         }
-        else if (server == "dods/0.0" && name == "server:") {
-            string value;
-            line >> value;
-            downcase(value);
-            DBG2(cout << name << ": " << value << endl);
+        else if (server == "dods/0.0" && name == "server") {
+            DBG2(cerr << name << ": " << value << endl);
             server = value;
         }
-       	else if (name == "location:") {
-       	    string value;
-       	    line >> value;
-       	    DBG2(cout << name << ": " << value << endl);
+       	else if (name == "location") {
+       	    DBG2(cerr << name << ": " << value << endl);
        	    location = value;
         }
-        else if (type == unknown_type && name == "content-type:"
-                 && line.str().find("text/html") != string::npos) {
-            DBG2(cout << name << ": text/html..." << endl);
+        else if (type == unknown_type && name == "content-type"
+                 && line.find("text/html") != string::npos) {
+            DBG2(cerr << name << ": text/html..." << endl);
             type = web_error;
         }
     }
@@ -412,7 +337,7 @@ HTTPConnect::www_lib_init()
     // Look to see if cookies are turned on in the .dodsrc file. If so,
     // activate here. We honor 'session cookies' (cookies without an
     // expiration date) here so that session-base SSO systems will work as
-    // expected.  
+    // expected.
     if (!d_cookie_jar.empty()) {
 	DBG(cerr << "Setting the cookie jar to: " << d_cookie_jar << endl);
         curl_easy_setopt(d_curl, CURLOPT_COOKIEJAR, d_cookie_jar.c_str());
@@ -472,7 +397,7 @@ HTTPConnect::read_url(const string &url, FILE *stream,
     curl_easy_setopt(d_curl, CURLOPT_URL, url.c_str());
 
 #ifdef WIN32
-    //  See the curl documentation for CURLOPT_FILE (nka CURLOPT_WRITEDATA)
+    //  See the curl documentation for CURLOPT_FILE (aka CURLOPT_WRITEDATA)
     //  and the CURLOPT_WRITEFUNCTION option.  Quote: "If you are using libcurl as
     //  a win32 DLL, you MUST use the CURLOPT_WRITEFUNCTION option if you set the
     //  CURLOPT_WRITEDATA option or you will experience crashes".  At the root of
@@ -495,9 +420,6 @@ HTTPConnect::read_url(const string &url, FILE *stream,
         req_hdrs = for_each(headers->begin(), headers->end(), req_hdrs);
     curl_easy_setopt(d_curl, CURLOPT_HTTPHEADER, req_hdrs.get_headers());
 
-    if (d_accept_deflate)
-        curl_easy_setopt(d_curl, CURLOPT_ENCODING, "deflate");
-
     // Turn off the proxy for this URL?
     bool temporary_proxy = false;
     if ((temporary_proxy = url_uses_no_proxy_for(url))) {
@@ -578,7 +500,7 @@ HTTPConnect::url_uses_no_proxy_for(const string &url) throw()
 
 HTTPConnect::HTTPConnect(RCReader *rcr) : d_username(""), d_password(""),
   					  d_cookie_jar(""),
-					  d_dap_client_protocol_major(2), 
+					  d_dap_client_protocol_major(2),
 					  d_dap_client_protocol_minor(0)
 
 {
@@ -702,9 +624,9 @@ HTTPConnect::fetch_url(const string &url)
 // methods to read from a stream returned by libcurl, not from a temporary
 // file. 9/21/07 jhrg
 static char *
-get_tempfile_template(char *file_template)
+get_tempfile_template(const char *file_template)
 {
-    char *c;
+    const char *c;
 
 #ifdef WIN32
     // whitelist for a WIN32 directory
@@ -796,8 +718,9 @@ void
 close_temp(FILE *s, const string &name)
 {
     int res = fclose(s);
-    if (res)
-        DBG(cerr << "Failed to close " << (void *)s << endl);
+    if (res) {
+	DBG(cerr << "Counld not close the temporary file: " << name << endl);
+    }
 
     unlink(name.c_str());
 }
