@@ -37,10 +37,23 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: UInt32.cc 20518 2009-03-05 23:39:46Z jimg $"
+    {"$Id: UInt32.cc 21699 2009-11-05 00:06:01Z jimg $"
     };
 
+#include "Byte.h"
+#include "Int16.h"
+#include "UInt16.h"
+#include "Int32.h"
 #include "UInt32.h"
+#include "Float32.h"
+#include "Float64.h"
+#include "Str.h"
+#include "Url.h"
+#include "Array.h"
+#include "Structure.h"
+#include "Sequence.h"
+#include "Grid.h"
+
 #include "DDS.h"
 #include "util.h"
 #include "parser.h"
@@ -180,7 +193,8 @@ UInt32::set_value(dods_uint32 i)
 
     return true;
 }
-//#if FILE_METHODS
+
+#if FILE_METHODS
 void
 UInt32::print_val(FILE *out, string space, bool print_decl_p)
 {
@@ -191,7 +205,8 @@ UInt32::print_val(FILE *out, string space, bool print_decl_p)
     else
         fprintf(out, "%u", (unsigned int)_buf) ;
 }
-//#endif
+#endif
+
 void
 UInt32::print_val(ostream &out, string space, bool print_decl_p)
 {
@@ -217,7 +232,7 @@ UInt32::ops(BaseType *b, int op)
     }
 
     // Extract the second arg's value.
-    if (!b || !b->read_p() && !b->read()) {
+    if (!b || !(b->read_p() || b->read())) {
         // Jose Garcia
         // Since the read method is virtual and implemented outside
         // libdap++ if we cannot read the data that is the problem
