@@ -1,23 +1,24 @@
-
-/* A Bison parser, made by GNU Bison 2.4.1.  */
+/* A Bison parser, made by GNU Bison 2.3.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-   
-   This program is free software: you can redistribute it and/or modify
+
+   This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 3 of the License, or
-   (at your option) any later version.
-   
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -28,7 +29,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -46,7 +47,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.4.1"
+#define YYBISON_VERSION "2.3"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -54,28 +55,59 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
-/* Push parsers.  */
-#define YYPUSH 0
-
-/* Pull parsers.  */
-#define YYPULL 1
-
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 /* Substitute the variable and function names.  */
-#define yyparse         dasparse
-#define yylex           daslex
-#define yyerror         daserror
-#define yylval          daslval
-#define yychar          daschar
-#define yydebug         dasdebug
-#define yynerrs         dasnerrs
+#define yyparse dasparse
+#define yylex   daslex
+#define yyerror daserror
+#define yylval  daslval
+#define yychar  daschar
+#define yydebug dasdebug
+#define yynerrs dasnerrs
+
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     SCAN_ATTR = 258,
+     SCAN_WORD = 259,
+     SCAN_ALIAS = 260,
+     SCAN_BYTE = 261,
+     SCAN_INT16 = 262,
+     SCAN_UINT16 = 263,
+     SCAN_INT32 = 264,
+     SCAN_UINT32 = 265,
+     SCAN_FLOAT32 = 266,
+     SCAN_FLOAT64 = 267,
+     SCAN_STRING = 268,
+     SCAN_URL = 269,
+     SCAN_XML = 270
+   };
+#endif
+/* Tokens.  */
+#define SCAN_ATTR 258
+#define SCAN_WORD 259
+#define SCAN_ALIAS 260
+#define SCAN_BYTE 261
+#define SCAN_INT16 262
+#define SCAN_UINT16 263
+#define SCAN_INT32 264
+#define SCAN_UINT32 265
+#define SCAN_FLOAT32 266
+#define SCAN_FLOAT64 267
+#define SCAN_STRING 268
+#define SCAN_URL 269
+#define SCAN_XML 270
+
+
 
 
 /* Copy the first part of user declarations.  */
-
-/* Line 189 of yacc.c  */
 #line 40 "das.y"
 
 
@@ -161,9 +193,6 @@ static void add_bad_attribute(AttrTable *attr, const string &type,
 
 
 
-/* Line 189 of yacc.c  */
-#line 166 "das.tab.cc"
-
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -182,44 +211,20 @@ static void add_bad_attribute(AttrTable *attr, const string &type,
 # define YYTOKEN_TABLE 0
 #endif
 
-
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     SCAN_ATTR = 258,
-     SCAN_WORD = 259,
-     SCAN_ALIAS = 260,
-     SCAN_BYTE = 261,
-     SCAN_INT16 = 262,
-     SCAN_UINT16 = 263,
-     SCAN_INT32 = 264,
-     SCAN_UINT32 = 265,
-     SCAN_FLOAT32 = 266,
-     SCAN_FLOAT64 = 267,
-     SCAN_STRING = 268,
-     SCAN_URL = 269,
-     SCAN_XML = 270
-   };
-#endif
-
-
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef int YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
+# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
+
 /* Copy the second part of user declarations.  */
 
 
-/* Line 264 of yacc.c  */
-#line 223 "das.tab.cc"
+/* Line 216 of yacc.c.  */
+#line 228 "das.tab.cc"
 
 #ifdef short
 # undef short
@@ -269,7 +274,7 @@ typedef short int yytype_int16;
 #define YYSIZE_MAXIMUM ((YYSIZE_T) -1)
 
 #ifndef YY_
-# if YYENABLE_NLS
+# if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
 #   define YY_(msgid) dgettext ("bison-runtime", msgid)
@@ -294,14 +299,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int yyi)
+YYID (int i)
 #else
 static int
-YYID (yyi)
-    int yyi;
+YYID (i)
+    int i;
 #endif
 {
-  return yyi;
+  return i;
 }
 #endif
 
@@ -382,9 +387,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss_alloc;
-  YYSTYPE yyvs_alloc;
-};
+  yytype_int16 yyss;
+  YYSTYPE yyvs;
+  };
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -418,12 +423,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
+# define YYSTACK_RELOCATE(Stack)					\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
-	Stack = &yyptr->Stack_alloc;					\
+	YYCOPY (&yyptr->Stack, Stack, yysize);				\
+	Stack = &yyptr->Stack;						\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -552,13 +557,12 @@ static const char *const yytname[] =
   "$end", "error", "$undefined", "SCAN_ATTR", "SCAN_WORD", "SCAN_ALIAS",
   "SCAN_BYTE", "SCAN_INT16", "SCAN_UINT16", "SCAN_INT32", "SCAN_UINT32",
   "SCAN_FLOAT32", "SCAN_FLOAT64", "SCAN_STRING", "SCAN_URL", "SCAN_XML",
-  "'{'", "'}'", "';'", "','", "$accept", "attr_start", "$@1", "attributes",
-  "attribute", "attr_list", "attr_tuple", "$@2", "$@3", "$@4", "$@5",
-  "$@6", "$@7", "$@8", "$@9", "$@10", "$@11", "$@12", "$@13", "$@14",
-  "$@15", "$@16", "$@17", "$@18", "$@19", "$@20", "$@21", "$@22", "$@23",
-  "$@24", "bytes", "int16", "uint16", "int32", "uint32", "float32",
-  "float64", "strs", "urls", "xml", "url", "str_or_id", "float_or_int",
-  "name", "alias", "$@25", "$@26", 0
+  "'{'", "'}'", "';'", "','", "$accept", "attr_start", "@1", "attributes",
+  "attribute", "attr_list", "attr_tuple", "@2", "@3", "@4", "@5", "@6",
+  "@7", "@8", "@9", "@10", "@11", "@12", "@13", "@14", "@15", "@16", "@17",
+  "@18", "@19", "@20", "@21", "@22", "@23", "@24", "bytes", "int16",
+  "uint16", "int32", "uint32", "float32", "float64", "strs", "urls", "xml",
+  "url", "str_or_id", "float_or_int", "name", "alias", "@25", "@26", 0
 };
 #endif
 
@@ -790,7 +794,7 @@ while (YYID (0))
    we won't break user code: when these are the locations we know.  */
 
 #ifndef YY_LOCATION_PRINT
-# if YYLTYPE_IS_TRIVIAL
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
 #  define YY_LOCATION_PRINT(File, Loc)			\
      fprintf (File, "%d.%d-%d.%d",			\
 	      (Loc).first_line, (Loc).first_column,	\
@@ -901,20 +905,17 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
+yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
 #else
 static void
-yy_stack_print (yybottom, yytop)
-    yytype_int16 *yybottom;
-    yytype_int16 *yytop;
+yy_stack_print (bottom, top)
+    yytype_int16 *bottom;
+    yytype_int16 *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; yybottom <= yytop; yybottom++)
-    {
-      int yybot = *yybottom;
-      YYFPRINTF (stderr, " %d", yybot);
-    }
+  for (; bottom <= top; ++bottom)
+    YYFPRINTF (stderr, " %d", *bottom);
   YYFPRINTF (stderr, "\n");
 }
 
@@ -948,11 +949,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
+      fprintf (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      YYFPRINTF (stderr, "\n");
+      fprintf (stderr, "\n");
     }
 }
 
@@ -1232,8 +1233,10 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
+
 
 /* Prevent warnings from -Wmissing-prototypes.  */
+
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1249,10 +1252,11 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-/* The lookahead symbol.  */
+
+/* The look-ahead symbol.  */
 int yychar;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1260,9 +1264,9 @@ int yynerrs;
 
 
 
-/*-------------------------.
-| yyparse or yypush_parse.  |
-`-------------------------*/
+/*----------.
+| yyparse.  |
+`----------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1286,39 +1290,14 @@ yyparse ()
 #endif
 #endif
 {
-
-
-    int yystate;
-    /* Number of tokens to shift before error messages enabled.  */
-    int yyerrstatus;
-
-    /* The stacks and their tools:
-       `yyss': related to states.
-       `yyvs': related to semantic values.
-
-       Refer to the stacks thru separate pointers, to allow yyoverflow
-       to reallocate them elsewhere.  */
-
-    /* The state stack.  */
-    yytype_int16 yyssa[YYINITDEPTH];
-    yytype_int16 *yyss;
-    yytype_int16 *yyssp;
-
-    /* The semantic value stack.  */
-    YYSTYPE yyvsa[YYINITDEPTH];
-    YYSTYPE *yyvs;
-    YYSTYPE *yyvsp;
-
-    YYSIZE_T yystacksize;
-
+  
+  int yystate;
   int yyn;
   int yyresult;
-  /* Lookahead token as an internal (translated) token number.  */
-  int yytoken;
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
+  /* Number of tokens to shift before error messages enabled.  */
+  int yyerrstatus;
+  /* Look-ahead token as an internal (translated) token number.  */
+  int yytoken = 0;
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1326,28 +1305,51 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
+  /* Three stacks and their tools:
+     `yyss': related to states,
+     `yyvs': related to semantic values,
+     `yyls': related to locations.
+
+     Refer to the stacks thru separate pointers, to allow yyoverflow
+     to reallocate them elsewhere.  */
+
+  /* The state stack.  */
+  yytype_int16 yyssa[YYINITDEPTH];
+  yytype_int16 *yyss = yyssa;
+  yytype_int16 *yyssp;
+
+  /* The semantic value stack.  */
+  YYSTYPE yyvsa[YYINITDEPTH];
+  YYSTYPE *yyvs = yyvsa;
+  YYSTYPE *yyvsp;
+
+
+
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
+  YYSIZE_T yystacksize = YYINITDEPTH;
+
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
+
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
-  yytoken = 0;
-  yyss = yyssa;
-  yyvs = yyvsa;
-  yystacksize = YYINITDEPTH;
-
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY; /* Cause a token to be read.  */
+  yychar = YYEMPTY;		/* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
+
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1377,6 +1379,7 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
+
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1384,6 +1387,7 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
+
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1406,8 +1410,9 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss_alloc, yyss);
-	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
+	YYSTACK_RELOCATE (yyss);
+	YYSTACK_RELOCATE (yyvs);
+
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1418,6 +1423,7 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
+
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1427,9 +1433,6 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
-  if (yystate == YYFINAL)
-    YYACCEPT;
-
   goto yybackup;
 
 /*-----------.
@@ -1438,16 +1441,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     lookahead token if we need one and don't already have one.  */
+     look-ahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1479,16 +1482,20 @@ yybackup:
       goto yyreduce;
     }
 
+  if (yyn == YYFINAL)
+    YYACCEPT;
+
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the lookahead token.  */
+  /* Shift the look-ahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token.  */
-  yychar = YYEMPTY;
+  /* Discard the shifted token unless it is eof.  */
+  if (yychar != YYEOF)
+    yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1528,8 +1535,6 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-
-/* Line 1455 of yacc.c  */
 #line 185 "das.y"
     {
 		name = new string();
@@ -1542,8 +1547,6 @@ yyreduce:
     break;
 
   case 3:
-
-/* Line 1455 of yacc.c  */
 #line 194 "das.y"
     {
 		POP;	// pop the DAS/AttrTable before stack's dtor
@@ -1554,8 +1557,6 @@ yyreduce:
     break;
 
   case 7:
-
-/* Line 1455 of yacc.c  */
 #line 209 "das.y"
     {
 		    parse_error((parser_arg *)arg, NO_DAS_MSG, das_line_num);
@@ -1563,148 +1564,106 @@ yyreduce:
     break;
 
   case 12:
-
-/* Line 1455 of yacc.c  */
 #line 221 "das.y"
     { save_str(*type, "Byte", das_line_num); ;}
     break;
 
   case 13:
-
-/* Line 1455 of yacc.c  */
 #line 222 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 15:
-
-/* Line 1455 of yacc.c  */
 #line 225 "das.y"
     { save_str(*type, "Int16", das_line_num); ;}
     break;
 
   case 16:
-
-/* Line 1455 of yacc.c  */
 #line 226 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 18:
-
-/* Line 1455 of yacc.c  */
 #line 229 "das.y"
     { save_str(*type, "UInt16", das_line_num); ;}
     break;
 
   case 19:
-
-/* Line 1455 of yacc.c  */
 #line 230 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 21:
-
-/* Line 1455 of yacc.c  */
 #line 233 "das.y"
     { save_str(*type, "Int32", das_line_num); ;}
     break;
 
   case 22:
-
-/* Line 1455 of yacc.c  */
 #line 234 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 24:
-
-/* Line 1455 of yacc.c  */
 #line 237 "das.y"
     { save_str(*type, "UInt32", das_line_num); ;}
     break;
 
   case 25:
-
-/* Line 1455 of yacc.c  */
 #line 238 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 27:
-
-/* Line 1455 of yacc.c  */
 #line 241 "das.y"
     { save_str(*type, "Float32", das_line_num); ;}
     break;
 
   case 28:
-
-/* Line 1455 of yacc.c  */
 #line 242 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 30:
-
-/* Line 1455 of yacc.c  */
 #line 245 "das.y"
     { save_str(*type, "Float64", das_line_num); ;}
     break;
 
   case 31:
-
-/* Line 1455 of yacc.c  */
 #line 246 "das.y"
     { save_str(*name, (yyvsp[(3) - (3)]), das_line_num); ;}
     break;
 
   case 33:
-
-/* Line 1455 of yacc.c  */
 #line 249 "das.y"
     { *type = "String"; ;}
     break;
 
   case 34:
-
-/* Line 1455 of yacc.c  */
 #line 250 "das.y"
     { *name = (yyvsp[(3) - (3)]); ;}
     break;
 
   case 36:
-
-/* Line 1455 of yacc.c  */
 #line 253 "das.y"
     { *type = "Url"; ;}
     break;
 
   case 37:
-
-/* Line 1455 of yacc.c  */
 #line 254 "das.y"
     { *name = (yyvsp[(3) - (3)]); ;}
     break;
 
   case 39:
-
-/* Line 1455 of yacc.c  */
 #line 257 "das.y"
     { *type = "OtherXML"; ;}
     break;
 
   case 40:
-
-/* Line 1455 of yacc.c  */
 #line 258 "das.y"
     { *name = (yyvsp[(3) - (3)]); ;}
     break;
 
   case 42:
-
-/* Line 1455 of yacc.c  */
 #line 262 "das.y"
     {
 		    DBG(cerr << "Processing ID: " << (yyvsp[(1) - (1)]) << endl);
@@ -1728,8 +1687,6 @@ yyreduce:
     break;
 
   case 43:
-
-/* Line 1455 of yacc.c  */
 #line 282 "das.y"
     {
 		    /* pop top of stack; store in attr_tab */
@@ -1739,8 +1696,6 @@ yyreduce:
     break;
 
   case 45:
-
-/* Line 1455 of yacc.c  */
 #line 290 "das.y"
     { 
 		    parse_error(ATTR_TUPLE_MSG, das_line_num, (yyvsp[(1) - (1)]));
@@ -1748,8 +1703,6 @@ yyreduce:
     break;
 
   case 47:
-
-/* Line 1455 of yacc.c  */
 #line 296 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_byte);
@@ -1757,8 +1710,6 @@ yyreduce:
     break;
 
   case 48:
-
-/* Line 1455 of yacc.c  */
 #line 300 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_byte);
@@ -1766,8 +1717,6 @@ yyreduce:
     break;
 
   case 49:
-
-/* Line 1455 of yacc.c  */
 #line 306 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_int16);
@@ -1775,8 +1724,6 @@ yyreduce:
     break;
 
   case 50:
-
-/* Line 1455 of yacc.c  */
 #line 310 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_int16);
@@ -1784,8 +1731,6 @@ yyreduce:
     break;
 
   case 51:
-
-/* Line 1455 of yacc.c  */
 #line 316 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_uint16);
@@ -1793,8 +1738,6 @@ yyreduce:
     break;
 
   case 52:
-
-/* Line 1455 of yacc.c  */
 #line 320 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_uint16);
@@ -1802,8 +1745,6 @@ yyreduce:
     break;
 
   case 53:
-
-/* Line 1455 of yacc.c  */
 #line 326 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_int32);
@@ -1811,8 +1752,6 @@ yyreduce:
     break;
 
   case 54:
-
-/* Line 1455 of yacc.c  */
 #line 330 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_int32);
@@ -1820,8 +1759,6 @@ yyreduce:
     break;
 
   case 55:
-
-/* Line 1455 of yacc.c  */
 #line 336 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_uint32);
@@ -1829,8 +1766,6 @@ yyreduce:
     break;
 
   case 56:
-
-/* Line 1455 of yacc.c  */
 #line 340 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_uint32);
@@ -1838,8 +1773,6 @@ yyreduce:
     break;
 
   case 57:
-
-/* Line 1455 of yacc.c  */
 #line 346 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_float32);
@@ -1847,8 +1780,6 @@ yyreduce:
     break;
 
   case 58:
-
-/* Line 1455 of yacc.c  */
 #line 350 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_float32);
@@ -1856,8 +1787,6 @@ yyreduce:
     break;
 
   case 59:
-
-/* Line 1455 of yacc.c  */
 #line 356 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_float64);
@@ -1865,8 +1794,6 @@ yyreduce:
     break;
 
   case 60:
-
-/* Line 1455 of yacc.c  */
 #line 360 "das.y"
     {
 		    add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_float64);
@@ -1874,8 +1801,6 @@ yyreduce:
     break;
 
   case 61:
-
-/* Line 1455 of yacc.c  */
 #line 366 "das.y"
     {
 		    string attr = remove_quotes((yyvsp[(1) - (1)]));
@@ -1884,8 +1809,6 @@ yyreduce:
     break;
 
   case 62:
-
-/* Line 1455 of yacc.c  */
 #line 371 "das.y"
     {
 		    string attr = remove_quotes((yyvsp[(3) - (3)]));
@@ -1894,8 +1817,6 @@ yyreduce:
     break;
 
   case 63:
-
-/* Line 1455 of yacc.c  */
 #line 378 "das.y"
     {
                     add_attribute(*type, *name, (yyvsp[(1) - (1)]), &check_url);
@@ -1903,8 +1824,6 @@ yyreduce:
     break;
 
   case 64:
-
-/* Line 1455 of yacc.c  */
 #line 382 "das.y"
     {
                     add_attribute(*type, *name, (yyvsp[(3) - (3)]), &check_url);
@@ -1912,8 +1831,6 @@ yyreduce:
     break;
 
   case 65:
-
-/* Line 1455 of yacc.c  */
 #line 388 "das.y"
     {
                     // XML must be quoted in the DAS but the quotes are an
@@ -1931,8 +1848,6 @@ yyreduce:
     break;
 
   case 82:
-
-/* Line 1455 of yacc.c  */
 #line 418 "das.y"
     { 
 		    *name = (yyvsp[(2) - (2)]);
@@ -1940,8 +1855,6 @@ yyreduce:
     break;
 
   case 83:
-
-/* Line 1455 of yacc.c  */
 #line 422 "das.y"
     {
 		    add_alias( DAS_OBJ(arg)->get_top_level_attributes(),
@@ -1950,9 +1863,8 @@ yyreduce:
     break;
 
 
-
-/* Line 1455 of yacc.c  */
-#line 1956 "das.tab.cc"
+/* Line 1267 of yacc.c.  */
+#line 1868 "das.tab.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1963,6 +1875,7 @@ yyreduce:
 
   *++yyvsp = yyval;
 
+
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2027,7 +1940,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2044,7 +1957,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2101,6 +2014,9 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
+  if (yyn == YYFINAL)
+    YYACCEPT;
+
   *++yyvsp = yylval;
 
 
@@ -2125,7 +2041,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#if !defined(yyoverflow) || YYERROR_VERBOSE
+#ifndef yyoverflow
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2136,7 +2052,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEMPTY)
+  if (yychar != YYEOF && yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2162,8 +2078,6 @@ yyreturn:
 }
 
 
-
-/* Line 1675 of yacc.c  */
 #line 429 "das.y"
 
 
