@@ -1,23 +1,24 @@
-
-/* A Bison parser, made by GNU Bison 2.4.1.  */
+/* A Bison parser, made by GNU Bison 2.3.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-   
-   This program is free software: you can redistribute it and/or modify
+
+   This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 3 of the License, or
-   (at your option) any later version.
-   
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -28,7 +29,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -46,7 +47,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.4.1"
+#define YYBISON_VERSION "2.3"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -54,28 +55,65 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
-/* Push parsers.  */
-#define YYPUSH 0
-
-/* Pull parsers.  */
-#define YYPULL 1
-
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 /* Substitute the variable and function names.  */
-#define yyparse         ddsparse
-#define yylex           ddslex
-#define yyerror         ddserror
-#define yylval          ddslval
-#define yychar          ddschar
-#define yydebug         ddsdebug
-#define yynerrs         ddsnerrs
+#define yyparse ddsparse
+#define yylex   ddslex
+#define yyerror ddserror
+#define yylval  ddslval
+#define yychar  ddschar
+#define yydebug ddsdebug
+#define yynerrs ddsnerrs
+
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     SCAN_WORD = 258,
+     SCAN_DATASET = 259,
+     SCAN_LIST = 260,
+     SCAN_SEQUENCE = 261,
+     SCAN_STRUCTURE = 262,
+     SCAN_FUNCTION = 263,
+     SCAN_GRID = 264,
+     SCAN_BYTE = 265,
+     SCAN_INT16 = 266,
+     SCAN_UINT16 = 267,
+     SCAN_INT32 = 268,
+     SCAN_UINT32 = 269,
+     SCAN_FLOAT32 = 270,
+     SCAN_FLOAT64 = 271,
+     SCAN_STRING = 272,
+     SCAN_URL = 273
+   };
+#endif
+/* Tokens.  */
+#define SCAN_WORD 258
+#define SCAN_DATASET 259
+#define SCAN_LIST 260
+#define SCAN_SEQUENCE 261
+#define SCAN_STRUCTURE 262
+#define SCAN_FUNCTION 263
+#define SCAN_GRID 264
+#define SCAN_BYTE 265
+#define SCAN_INT16 266
+#define SCAN_UINT16 267
+#define SCAN_INT32 268
+#define SCAN_UINT32 269
+#define SCAN_FLOAT32 270
+#define SCAN_FLOAT64 271
+#define SCAN_STRING 272
+#define SCAN_URL 273
+
+
 
 
 /* Copy the first part of user declarations.  */
-
-/* Line 189 of yacc.c  */
 #line 47 "dds.y"
 
 
@@ -149,9 +187,6 @@ void invalid_declaration(parser_arg *arg, string semantic_err_msg,
 
 
 
-/* Line 189 of yacc.c  */
-#line 154 "dds.tab.cc"
-
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -170,60 +205,28 @@ void invalid_declaration(parser_arg *arg, string semantic_err_msg,
 # define YYTOKEN_TABLE 0
 #endif
 
-
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     SCAN_WORD = 258,
-     SCAN_DATASET = 259,
-     SCAN_LIST = 260,
-     SCAN_SEQUENCE = 261,
-     SCAN_STRUCTURE = 262,
-     SCAN_FUNCTION = 263,
-     SCAN_GRID = 264,
-     SCAN_BYTE = 265,
-     SCAN_INT16 = 266,
-     SCAN_UINT16 = 267,
-     SCAN_INT32 = 268,
-     SCAN_UINT32 = 269,
-     SCAN_FLOAT32 = 270,
-     SCAN_FLOAT64 = 271,
-     SCAN_STRING = 272,
-     SCAN_URL = 273
-   };
-#endif
-
-
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-{
-
-/* Line 214 of yacc.c  */
 #line 121 "dds.y"
-
+{
     bool boolean;
     char word[ID_MAX];
-
-
-
-/* Line 214 of yacc.c  */
-#line 215 "dds.tab.cc"
-} YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
+}
+/* Line 193 of yacc.c.  */
+#line 217 "dds.tab.cc"
+	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
+# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
+
 /* Copy the second part of user declarations.  */
 
 
-/* Line 264 of yacc.c  */
-#line 227 "dds.tab.cc"
+/* Line 216 of yacc.c.  */
+#line 230 "dds.tab.cc"
 
 #ifdef short
 # undef short
@@ -273,7 +276,7 @@ typedef short int yytype_int16;
 #define YYSIZE_MAXIMUM ((YYSIZE_T) -1)
 
 #ifndef YY_
-# if YYENABLE_NLS
+# if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
 #   define YY_(msgid) dgettext ("bison-runtime", msgid)
@@ -298,14 +301,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int yyi)
+YYID (int i)
 #else
 static int
-YYID (yyi)
-    int yyi;
+YYID (i)
+    int i;
 #endif
 {
-  return yyi;
+  return i;
 }
 #endif
 
@@ -386,9 +389,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss_alloc;
-  YYSTYPE yyvs_alloc;
-};
+  yytype_int16 yyss;
+  YYSTYPE yyvs;
+  };
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -422,12 +425,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
+# define YYSTACK_RELOCATE(Stack)					\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
-	Stack = &yyptr->Stack_alloc;					\
+	YYCOPY (&yyptr->Stack, Stack, yysize);				\
+	Stack = &yyptr->Stack;						\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -543,10 +546,10 @@ static const char *const yytname[] =
   "SCAN_SEQUENCE", "SCAN_STRUCTURE", "SCAN_FUNCTION", "SCAN_GRID",
   "SCAN_BYTE", "SCAN_INT16", "SCAN_UINT16", "SCAN_INT32", "SCAN_UINT32",
   "SCAN_FLOAT32", "SCAN_FLOAT64", "SCAN_STRING", "SCAN_URL", "'{'", "'}'",
-  "';'", "':'", "'['", "']'", "'='", "$accept", "start", "$@1", "datasets",
-  "dataset", "declarations", "declaration", "$@2", "$@3", "$@4", "$@5",
-  "$@6", "structure", "sequence", "grid", "base_type", "var", "var_name",
-  "array_decl", "$@7", "$@8", "name", 0
+  "';'", "':'", "'['", "']'", "'='", "$accept", "start", "@1", "datasets",
+  "dataset", "declarations", "declaration", "@2", "@3", "@4", "@5", "@6",
+  "structure", "sequence", "grid", "base_type", "var", "var_name",
+  "array_decl", "@7", "@8", "name", 0
 };
 #endif
 
@@ -770,7 +773,7 @@ while (YYID (0))
    we won't break user code: when these are the locations we know.  */
 
 #ifndef YY_LOCATION_PRINT
-# if YYLTYPE_IS_TRIVIAL
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
 #  define YY_LOCATION_PRINT(File, Loc)			\
      fprintf (File, "%d.%d-%d.%d",			\
 	      (Loc).first_line, (Loc).first_column,	\
@@ -881,20 +884,17 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
+yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
 #else
 static void
-yy_stack_print (yybottom, yytop)
-    yytype_int16 *yybottom;
-    yytype_int16 *yytop;
+yy_stack_print (bottom, top)
+    yytype_int16 *bottom;
+    yytype_int16 *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; yybottom <= yytop; yybottom++)
-    {
-      int yybot = *yybottom;
-      YYFPRINTF (stderr, " %d", yybot);
-    }
+  for (; bottom <= top; ++bottom)
+    YYFPRINTF (stderr, " %d", *bottom);
   YYFPRINTF (stderr, "\n");
 }
 
@@ -928,11 +928,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
+      fprintf (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      YYFPRINTF (stderr, "\n");
+      fprintf (stderr, "\n");
     }
 }
 
@@ -1212,8 +1212,10 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
+
 
 /* Prevent warnings from -Wmissing-prototypes.  */
+
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1229,10 +1231,11 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-/* The lookahead symbol.  */
+
+/* The look-ahead symbol.  */
 int yychar;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1240,9 +1243,9 @@ int yynerrs;
 
 
 
-/*-------------------------.
-| yyparse or yypush_parse.  |
-`-------------------------*/
+/*----------.
+| yyparse.  |
+`----------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1266,39 +1269,14 @@ yyparse ()
 #endif
 #endif
 {
-
-
-    int yystate;
-    /* Number of tokens to shift before error messages enabled.  */
-    int yyerrstatus;
-
-    /* The stacks and their tools:
-       `yyss': related to states.
-       `yyvs': related to semantic values.
-
-       Refer to the stacks thru separate pointers, to allow yyoverflow
-       to reallocate them elsewhere.  */
-
-    /* The state stack.  */
-    yytype_int16 yyssa[YYINITDEPTH];
-    yytype_int16 *yyss;
-    yytype_int16 *yyssp;
-
-    /* The semantic value stack.  */
-    YYSTYPE yyvsa[YYINITDEPTH];
-    YYSTYPE *yyvs;
-    YYSTYPE *yyvsp;
-
-    YYSIZE_T yystacksize;
-
+  
+  int yystate;
   int yyn;
   int yyresult;
-  /* Lookahead token as an internal (translated) token number.  */
-  int yytoken;
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
+  /* Number of tokens to shift before error messages enabled.  */
+  int yyerrstatus;
+  /* Look-ahead token as an internal (translated) token number.  */
+  int yytoken = 0;
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1306,28 +1284,51 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
+  /* Three stacks and their tools:
+     `yyss': related to states,
+     `yyvs': related to semantic values,
+     `yyls': related to locations.
+
+     Refer to the stacks thru separate pointers, to allow yyoverflow
+     to reallocate them elsewhere.  */
+
+  /* The state stack.  */
+  yytype_int16 yyssa[YYINITDEPTH];
+  yytype_int16 *yyss = yyssa;
+  yytype_int16 *yyssp;
+
+  /* The semantic value stack.  */
+  YYSTYPE yyvsa[YYINITDEPTH];
+  YYSTYPE *yyvs = yyvsa;
+  YYSTYPE *yyvsp;
+
+
+
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
+  YYSIZE_T yystacksize = YYINITDEPTH;
+
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
+
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
-  yytoken = 0;
-  yyss = yyssa;
-  yyvs = yyvsa;
-  yystacksize = YYINITDEPTH;
-
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY; /* Cause a token to be read.  */
+  yychar = YYEMPTY;		/* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
+
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1357,6 +1358,7 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
+
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1364,6 +1366,7 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
+
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1386,8 +1389,9 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss_alloc, yyss);
-	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
+	YYSTACK_RELOCATE (yyss);
+	YYSTACK_RELOCATE (yyvs);
+
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1398,6 +1402,7 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
+
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1407,9 +1412,6 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
-  if (yystate == YYFINAL)
-    YYACCEPT;
-
   goto yybackup;
 
 /*-----------.
@@ -1418,16 +1420,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     lookahead token if we need one and don't already have one.  */
+     look-ahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1459,16 +1461,20 @@ yybackup:
       goto yyreduce;
     }
 
+  if (yyn == YYFINAL)
+    YYACCEPT;
+
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the lookahead token.  */
+  /* Shift the look-ahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token.  */
-  yychar = YYEMPTY;
+  /* Discard the shifted token unless it is eof.  */
+  if (yychar != YYEOF)
+    yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1508,8 +1514,6 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-
-/* Line 1455 of yacc.c  */
 #line 150 "dds.y"
     {
 		    /* On entry to the parser, make the BaseType stack. */
@@ -1518,8 +1522,6 @@ yyreduce:
     break;
 
   case 3:
-
-/* Line 1455 of yacc.c  */
 #line 155 "dds.y"
     {
 		    delete ctor; ctor = 0;
@@ -1527,8 +1529,6 @@ yyreduce:
     break;
 
   case 6:
-
-/* Line 1455 of yacc.c  */
 #line 165 "dds.y"
     {
 		    (yyval.boolean) = (yyvsp[(3) - (6)].boolean) && (yyvsp[(5) - (6)].word);
@@ -1536,8 +1536,6 @@ yyreduce:
     break;
 
   case 7:
-
-/* Line 1455 of yacc.c  */
 #line 169 "dds.y"
     {
 		    parse_error((parser_arg *)arg, NO_DDS_MSG,
@@ -1548,8 +1546,6 @@ yyreduce:
     break;
 
   case 8:
-
-/* Line 1455 of yacc.c  */
 #line 178 "dds.y"
     {
 		    (yyval.boolean) = true;
@@ -1557,22 +1553,16 @@ yyreduce:
     break;
 
   case 9:
-
-/* Line 1455 of yacc.c  */
 #line 182 "dds.y"
     { (yyval.boolean) = true; ;}
     break;
 
   case 10:
-
-/* Line 1455 of yacc.c  */
 #line 183 "dds.y"
     { (yyval.boolean) = true; ;}
     break;
 
   case 11:
-
-/* Line 1455 of yacc.c  */
 #line 191 "dds.y"
     { 
 		    string smsg;
@@ -1597,8 +1587,6 @@ yyreduce:
     break;
 
   case 12:
-
-/* Line 1455 of yacc.c  */
 #line 213 "dds.y"
     { 
 		    if( current ) delete current ;
@@ -1608,8 +1596,6 @@ yyreduce:
     break;
 
   case 13:
-
-/* Line 1455 of yacc.c  */
 #line 219 "dds.y"
     { 
 		    string smsg;
@@ -1626,8 +1612,6 @@ yyreduce:
     break;
 
   case 14:
-
-/* Line 1455 of yacc.c  */
 #line 233 "dds.y"
     { 
 		    if( current ) delete current ;
@@ -1637,8 +1621,6 @@ yyreduce:
     break;
 
   case 15:
-
-/* Line 1455 of yacc.c  */
 #line 239 "dds.y"
     { 
 		    string smsg;
@@ -1655,8 +1637,6 @@ yyreduce:
     break;
 
   case 16:
-
-/* Line 1455 of yacc.c  */
 #line 253 "dds.y"
     { 
 		    if (is_keyword(string((yyvsp[(3) - (4)].word)), "array"))
@@ -1672,8 +1652,6 @@ yyreduce:
     break;
 
   case 17:
-
-/* Line 1455 of yacc.c  */
 #line 265 "dds.y"
     { 
 		    if (is_keyword(string((yyvsp[(7) - (8)].word)), "maps"))
@@ -1689,8 +1667,6 @@ yyreduce:
     break;
 
   case 18:
-
-/* Line 1455 of yacc.c  */
 #line 277 "dds.y"
     {
 		    if( current ) delete current ;
@@ -1700,8 +1676,6 @@ yyreduce:
     break;
 
   case 19:
-
-/* Line 1455 of yacc.c  */
 #line 283 "dds.y"
     {
 		    string smsg;
@@ -1720,8 +1694,6 @@ yyreduce:
     break;
 
   case 20:
-
-/* Line 1455 of yacc.c  */
 #line 299 "dds.y"
     {
 		    ostringstream msg;
@@ -1733,8 +1705,6 @@ yyreduce:
     break;
 
   case 21:
-
-/* Line 1455 of yacc.c  */
 #line 310 "dds.y"
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewStructure()); 
@@ -1742,8 +1712,6 @@ yyreduce:
     break;
 
   case 22:
-
-/* Line 1455 of yacc.c  */
 #line 316 "dds.y"
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewSequence()); 
@@ -1751,8 +1719,6 @@ yyreduce:
     break;
 
   case 23:
-
-/* Line 1455 of yacc.c  */
 #line 322 "dds.y"
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewGrid()); 
@@ -1760,78 +1726,56 @@ yyreduce:
     break;
 
   case 24:
-
-/* Line 1455 of yacc.c  */
 #line 327 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewByte(); ;}
     break;
 
   case 25:
-
-/* Line 1455 of yacc.c  */
 #line 328 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt16(); ;}
     break;
 
   case 26:
-
-/* Line 1455 of yacc.c  */
 #line 329 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt16(); ;}
     break;
 
   case 27:
-
-/* Line 1455 of yacc.c  */
 #line 330 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt32(); ;}
     break;
 
   case 28:
-
-/* Line 1455 of yacc.c  */
 #line 331 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt32(); ;}
     break;
 
   case 29:
-
-/* Line 1455 of yacc.c  */
 #line 332 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat32(); ;}
     break;
 
   case 30:
-
-/* Line 1455 of yacc.c  */
 #line 333 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat64(); ;}
     break;
 
   case 31:
-
-/* Line 1455 of yacc.c  */
 #line 334 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewStr(); ;}
     break;
 
   case 32:
-
-/* Line 1455 of yacc.c  */
 #line 335 "dds.y"
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUrl(); ;}
     break;
 
   case 33:
-
-/* Line 1455 of yacc.c  */
 #line 338 "dds.y"
     { current->set_name((yyvsp[(1) - (1)].word)); ;}
     break;
 
   case 49:
-
-/* Line 1455 of yacc.c  */
 #line 349 "dds.y"
     { 
 		     if (!check_int32((yyvsp[(2) - (3)].word))) {
@@ -1857,8 +1801,6 @@ yyreduce:
     break;
 
   case 50:
-
-/* Line 1455 of yacc.c  */
 #line 372 "dds.y"
     {
 		     id = new string((yyvsp[(2) - (2)].word));
@@ -1866,8 +1808,6 @@ yyreduce:
     break;
 
   case 51:
-
-/* Line 1455 of yacc.c  */
 #line 376 "dds.y"
     { 
 		     if (!check_int32((yyvsp[(5) - (5)].word))) {
@@ -1894,8 +1834,6 @@ yyreduce:
     break;
 
   case 52:
-
-/* Line 1455 of yacc.c  */
 #line 399 "dds.y"
     {
 		     (yyval.boolean) = true;
@@ -1903,8 +1841,6 @@ yyreduce:
     break;
 
   case 53:
-
-/* Line 1455 of yacc.c  */
 #line 404 "dds.y"
     {
 		     ostringstream msg;
@@ -1917,22 +1853,16 @@ yyreduce:
     break;
 
   case 54:
-
-/* Line 1455 of yacc.c  */
 #line 414 "dds.y"
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[(1) - (1)].word)); ;}
     break;
 
   case 55:
-
-/* Line 1455 of yacc.c  */
 #line 415 "dds.y"
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[(1) - (1)].word)); ;}
     break;
 
   case 56:
-
-/* Line 1455 of yacc.c  */
 #line 417 "dds.y"
     {
 		  ostringstream msg;
@@ -1945,9 +1875,8 @@ yyreduce:
     break;
 
 
-
-/* Line 1455 of yacc.c  */
-#line 1951 "dds.tab.cc"
+/* Line 1267 of yacc.c.  */
+#line 1880 "dds.tab.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1958,6 +1887,7 @@ yyreduce:
 
   *++yyvsp = yyval;
 
+
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2022,7 +1952,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2039,7 +1969,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2096,6 +2026,9 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
+  if (yyn == YYFINAL)
+    YYACCEPT;
+
   *++yyvsp = yylval;
 
 
@@ -2120,7 +2053,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#if !defined(yyoverflow) || YYERROR_VERBOSE
+#ifndef yyoverflow
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2131,7 +2064,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEMPTY)
+  if (yychar != YYEOF && yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2157,8 +2090,6 @@ yyreturn:
 }
 
 
-
-/* Line 1675 of yacc.c  */
 #line 427 "dds.y"
 
 
