@@ -30,12 +30,13 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    {"$Id: util_mit.cc 18315 2008-03-03 20:14:44Z jimg $"
+    {"$Id: util_mit.cc 21214 2009-08-04 16:15:54Z jimg $"
     };
 
+#include <cstdio>
 #include <cstring>
 #include <cstdlib>
-#include <string>
+//#include <string>
 #include <ctype.h>
 
 #ifndef TM_IN_SYS_TIME
@@ -59,13 +60,13 @@ using std::string;
 
 namespace libdap {
 
-static char * months[12] =
+static const char * months[12] =
     {
         "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
     };
 
 #ifndef HAVE_STRFTIME
-static char * wkdays[7] =
+static const char * wkdays[7] =
     {
         "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"
     };
